You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@trafficserver.apache.org by no...@apache.org on 2017/01/03 20:59:39 UTC

[trafficserver] branch master updated: TS-5059: SSL_set_rbio() renamed SSL_set0_rbio()

This is an automated email from the ASF dual-hosted git repository.

nottheoilrig pushed a commit to branch master
in repository https://git-dual.apache.org/repos/asf/trafficserver.git

The following commit(s) were added to refs/heads/master by this push:
       new  1a08a61   TS-5059: SSL_set_rbio() renamed SSL_set0_rbio()
1a08a61 is described below

commit 1a08a61f86c0c08871961e5386e44f88bacccbe8
Author: Jack Bates <ja...@nottheoilrig.com>
AuthorDate: Mon Jan 2 14:25:09 2017 -0700

    TS-5059: SSL_set_rbio() renamed SSL_set0_rbio()
    
    It was renamed before OpenSSL 1.1 was released [1][2].
    
    [1] https://github.com/openssl/openssl/commit/65e2d672548e7c4bcb28f1c5c835362830b1745b
    [2] https://rt.openssl.org/Ticket/Display.html?id=4572
---
 build/crypto.m4                 | 4 ++--
 configure.ac                    | 2 +-
 iocore/net/SSLInternal.cc       | 4 ++--
 iocore/net/SSLNetVConnection.cc | 6 +++---
 4 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/build/crypto.m4 b/build/crypto.m4
index 2f3bb0d..dc6fbd8 100644
--- a/build/crypto.m4
+++ b/build/crypto.m4
@@ -168,7 +168,7 @@ AC_DEFUN([TS_CHECK_CRYPTO_SET_RBIO], [
   enable_set_rbio=yes
 
   TS_ADDTO(LIBS, [$OPENSSL_LIBS])
-  AC_MSG_CHECKING([for SSL_set_rbio])
+  AC_MSG_CHECKING([for SSL_set0_rbio])
   AC_LINK_IFELSE(
   [
     AC_LANG_PROGRAM([[
@@ -179,7 +179,7 @@ AC_DEFUN([TS_CHECK_CRYPTO_SET_RBIO], [
 #include <openssl/tls1.h>
 #endif
       ]],
-      [[SSL_set_rbio(NULL, NULL);]])
+      [[SSL_set0_rbio(NULL, NULL);]])
   ],
   [
     AC_MSG_RESULT([yes])
diff --git a/configure.ac b/configure.ac
index f906135..e7b29ed 100644
--- a/configure.ac
+++ b/configure.ac
@@ -1122,7 +1122,7 @@ TS_CHECK_CRYPTO_SNI
 TS_CHECK_CRYPTO_CERT_CB
 
 #
-# Check for SSL_set_rbio call
+# Check for SSL_set0_rbio call
 TS_CHECK_CRYPTO_SET_RBIO
 
 # Check for DH_get_2048_256
diff --git a/iocore/net/SSLNetVConnection.cc b/iocore/net/SSLNetVConnection.cc
index bad8be1..bba0191 100644
--- a/iocore/net/SSLNetVConnection.cc
+++ b/iocore/net/SSLNetVConnection.cc
@@ -37,7 +37,7 @@
 #if !TS_USE_SET_RBIO
 // Defined in SSLInternal.c, should probably make a separate include
 // file for this at some point
-void SSL_set_rbio(SSL *ssl, BIO *rbio);
+void SSL_set0_rbio(SSL *ssl, BIO *rbio);
 #endif
 
 // This is missing from BoringSSL
@@ -391,7 +391,7 @@ SSLNetVConnection::read_raw_data()
   // Must be reset on each read
   BIO *rbio = BIO_new_mem_buf(start, this->handShakeBioStored);
   BIO_set_mem_eof_return(rbio, -1);
-  SSL_set_rbio(this->ssl, rbio);
+  SSL_set0_rbio(this->ssl, rbio);
 
   return r;
 }
@@ -565,7 +565,7 @@ SSLNetVConnection::net_read_io(NetHandler *nh, EThread *lthread)
         // Must be reset on each read
         BIO *rbio = BIO_new_mem_buf(start, this->handShakeBioStored);
         BIO_set_mem_eof_return(rbio, -1);
-        SSL_set_rbio(this->ssl, rbio);
+        SSL_set0_rbio(this->ssl, rbio);
       }
     }
   }

diff --git a/iocore/net/SSLInternal.cc b/iocore/net/SSLInternal.cc
index fcc042a..196c38b 100644
--- a/iocore/net/SSLInternal.cc
+++ b/iocore/net/SSLInternal.cc
@@ -23,7 +23,7 @@
  */
 #include "ts/ink_config.h"
 #if TS_USE_SET_RBIO
 // No need to do anything, this version of openssl provides the SSL_set_rbio function
 #else
 
 #ifdef OPENSSL_NO_SSL_INTERN
@@ -35,7 +35,7 @@
 #include "P_SSLNetVConnection.h"
 
 void
-SSL_set_rbio(SSL *ssl, BIO *rbio)
+SSL_set0_rbio(SSL *ssl, BIO *rbio)
 {
   if (ssl->rbio != nullptr) {
     BIO_free(ssl->rbio);
@@ -23,7 +23,7 @@
 #include "ts/ink_config.h"
 #if TS_USE_SET_RBIO
-// No need to do anything, this version of openssl provides the SSL_set_rbio function
+// No need to do anything, this version of openssl provides the SSL_set0_rbio function
 #else
 
-- 
To stop receiving notification emails like this one, please contact
['"commits@trafficserver.apache.org" <co...@trafficserver.apache.org>'].